==> estateplat-common-1.2.4-20230613.024725-1178-sources.jar: cn/gtmap/estateplat/model/server/core/BdcHysyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;

/**
 * 海域（含无居民海岛） 使用权登记信息
 * Created by lst on 2015/3/18
 */
@Table(name = "bdc_hysyq")
public class BdcHysyq extends QllxParent implements QllxVo {
    /* @Id
     private String qlid;//权利Id
     private String bdcdyid;//不动产单元Id*/
    private Date syksqx;//使用开始期限
    private Date syjsqx;//使用结束期限
    private Double syzje;//使用总金额（万元）
    private String syjyj;//使用金标准依据
    private String syjjnqk;//使用金缴纳情况

    private Double syqmj;//使用权面积(公顷)

    private String qllx;//权利类型
    /* private String proid;//项目ID*/
    private String gyqk;//共有情况

    private String fj;//附记
    private String ywh;//业务号

    private Integer qszt;//权属状态

    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登薄时间
    private String zxywh;//注销业务号
    private String xmmc;//项目名称

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description bdc_hysyq表增加冗余字段bdcdyh、bdcdybh、zl
     */
    private String bdcdyh; //不动产单元号

    private String bdcdybh; //不动产单元编号

    private String zl; //坐落
    private String qlqtzk; //权利其他状况

    private Integer cxzt;//撤销状态 1：已撤销,0或空：未撤销


    private String jedw;//金额单位 字典表BDC_ZD_JEDW
    private String syjjkpz;//使用金缴款凭证
    private String hyglh;//海域（海岛）管理号
    private String hydjh;//海域登记号
    private String bhyy;//变化原因
    private String bhnr;//变化内容

    public String getJedw() {
        return jedw;
    }

    public void setJedw(String jedw) {
        this.jedw = jedw;
    }

    public String getSyjjkpz() {
        return syjjkpz;
    }

    public void setSyjjkpz(String syjjkpz) {
        this.syjjkpz = syjjkpz;
    }

    public String getHyglh() {
        return hyglh;
    }

    public void setHyglh(String hyglh) {
        this.hyglh = hyglh;
    }

    public Integer getCxzt() {
        return cxzt;
    }

    public void setCxzt(Integer cxzt) {
        this.cxzt = cxzt;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }


    public Date getSyksqx() {
        return syksqx;
    }

    public void setSyksqx(Date syksqx) {
        this.syksqx = syksqx;
    }

    public Date getSyjsqx() {
        return syjsqx;
    }

    public void setSyjsqx(Date syjsqx) {
        this.syjsqx = syjsqx;
    }

    public Double getSyzje() {
        return syzje;
    }

    public void setSyzje(Double syzje) {
        this.syzje = syzje;
    }

    public String getSyjyj() {
        return syjyj;
    }

    public void setSyjyj(String syjyj) {
        this.syjyj = syjyj;
    }

    public String getSyjjnqk() {
        return syjjnqk;
    }

    public void setSyjjnqk(String syjjnqk) {
        this.syjjnqk = syjjnqk;
    }

    public Double getSyqmj() {
        return syqmj;
    }

    public void setSyqmj(Double syqmj) {
        this.syqmj = syqmj;
    }

    @Override
    public String getQllx() {
        return qllx;
    }

    @Override
    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    @Override
    public String getGyqk() {
        return gyqk;
    }

    @Override
    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    @Override
    public String getFj() {
        return fj;
    }

    @Override
    public void setFj(String fj) {
        this.fj = fj;
    }

    @Override
    public String getYwh() {
        return ywh;
    }

    @Override
    public void setYwh(String ywh) {
        this.ywh = ywh;
    }


    @Override
    public Integer getQszt() {
        return qszt;
    }

    @Override
    public void setQszt(Integer qszt) {
        this.qszt = qszt;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getQlqtzk() {
        return qlqtzk;
    }

    public void setQlqtzk(String qlqtzk) {
        this.qlqtzk = qlqtzk;
    }

    public String getZxywh() {
        return zxywh;
    }

    public void setZxywh(String zxywh) {
        this.zxywh = zxywh;
    }

    public String getHydjh() {
        return hydjh;
    }

    public void setHydjh(String hydjh) {
        this.hydjh = hydjh;
    }

    public String getBhyy() {
        return bhyy;
    }

    public void setBhyy(String bhyy) {
        this.bhyy = bhyy;
    }

    public String getBhnr() {
        return bhnr;
    }

    public void setBhnr(String bhnr) {
        this.bhnr = bhnr;
    }
}

==> estateplat-common-1.2.4-20231101.012950-1195-sources.jar: cn/gtmap/estateplat/model/server/core/BdcHysyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * 海域（含无居民海岛） 使用权登记信息
 * Created by lst on 2015/3/18
 */
@Table(name = "bdc_hysyq")
public class BdcHysyq extends QllxParent implements QllxVo {
    //@Id
    //private String qlid;//权利Id
    //private String bdcdyid;//不动产单元Id
    private Date syksqx;//使用开始期限
    private Date syjsqx;//使用结束期限
    private Double syzje;//使用总金额（万元）
    private String syjyj;//使用金标准依据
    private String syjjnqk;//使用金缴纳情况

    private Double syqmj;//使用权面积(公顷)

    private String qllx;//权利类型
    //private String proid;//项目ID
    private String gyqk;//共有情况

    private String fj;//附记
    private String ywh;//业务号

    private Integer qszt;//权属状态

    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登薄时间
    private String zxywh;//注销业务号
    private String xmmc;//项目名称

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description bdc_hysyq表增加冗余字段bdcdyh、bdcdybh、zl
     */
    private String bdcdyh; //不动产单元号

    private String bdcdybh; //不动产单元编号

    private String zl; //坐落
    private String qlqtzk; //权利其他状况

    private Integer cxzt;//撤销状态 1：已撤销,0或空：未撤销


    private String jedw;//金额单位 字典表BDC_ZD_JEDW
    private String syjjkpz;//使用金缴款凭证
    private String hyglh;//海域（海岛）管理号
    private String hydjh;//海域登记号
    private String bhyy;//变化原因
    private String bhnr;//变化内容

    public String getJedw() {
        return jedw;
    }

    public void setJedw(String jedw) {
        this.jedw = jedw;
    }

    public String getSyjjkpz() {
        return syjjkpz;
    }

    public void setSyjjkpz(String syjjkpz) {
        this.syjjkpz = syjjkpz;
    }

    public String getHyglh() {
        return hyglh;
    }

    public void setHyglh(String hyglh) {
        this.hyglh = hyglh;
    }

    public Integer getCxzt() {
        return cxzt;
    }

    public void setCxzt(Integer cxzt) {
        this.cxzt = cxzt;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }


    public Date getSyksqx() {
        return syksqx;
    }

    public void setSyksqx(Date syksqx) {
        this.syksqx = syksqx;
    }

    public Date getSyjsqx() {
        return syjsqx;
    }

    public void setSyjsqx(Date syjsqx) {
        this.syjsqx = syjsqx;
    }

    public Double getSyzje() {
        return syzje;
    }

    public void setSyzje(Double syzje) {
        this.syzje = syzje;
    }

    public String getSyjyj() {
        return syjyj;
    }

    public void setSyjyj(String syjyj) {
        this.syjyj = syjyj;
    }

    public String getSyjjnqk() {
        return syjjnqk;
    }

    public void setSyjjnqk(String syjjnqk) {
        this.syjjnqk = syjjnqk;
    }

    public Double getSyqmj() {
        return syqmj;
    }

    public void setSyqmj(Double syqmj) {
        this.syqmj = syqmj;
    }

    @Override
    public String getQllx() {
        return qllx;
    }

    @Override
    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    @Override
    public String getGyqk() {
        return gyqk;
    }

    @Override
    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    @Override
    public String getFj() {
        return fj;
    }

    @Override
    public void setFj(String fj) {
        this.fj = fj;
    }

    @Override
    public String getYwh() {
        return ywh;
    }

    @Override
    public void setYwh(String ywh) {
        this.ywh = ywh;
    }


    @Override
    public Integer getQszt() {
        return qszt;
    }

    @Override
    public void setQszt(Integer qszt) {
        this.qszt = qszt;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getQlqtzk() {
        return qlqtzk;
    }

    public void setQlqtzk(String qlqtzk) {
        this.qlqtzk = qlqtzk;
    }

    public String getZxywh() {
        return zxywh;
    }

    public void setZxywh(String zxywh) {
        this.zxywh = zxywh;
    }

    public String getHydjh() {
        return hydjh;
    }

    public void setHydjh(String hydjh) {
        this.hydjh = hydjh;
    }

    public String getBhyy() {
        return bhyy;
    }

    public void setBhyy(String bhyy) {
        this.bhyy = bhyy;
    }

    public String getBhnr() {
        return bhnr;
    }

    public void setBhnr(String bhnr) {
        this.bhnr = bhnr;
    }

    @Override
    public String getQlid() {
        return qlid;
    }

    @Override
    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    @Override
    public String getBdcdyid() {
        return bdcdyid;
    }

    @Override
    public void setBdcdyid(String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    @Override
    public String getProid() {
        return proid;
    }

    @Override
    public void setProid(String proid) {
        this.proid = proid;
    }
}
